---
title: llarp::layers::platform::PlatformDriver_Base
summary: base type that is responsible for bridging the os and the flow layer. 

---

# llarp::layers::platform::PlatformDriver_Base



base type that is responsible for bridging the os and the flow layer.  [More...](#detailed-description)


`#include <driver_base.hpp>`

## Public Functions

|                | Name           |
| -------------- | -------------- |
| virtual | **[~PlatformDriver_Base](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-~platformdriver-base)**() =default |
| bool | **[peek_platform](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-peek-platform)**() const<br>peek if we have packets from the os to read.  |
| bool | **[peek_flow](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-peek-flow)**() const<br>peek if we have things from the flow layer to read.  |

## Protected Functions

|                | Name           |
| -------------- | -------------- |
| virtual void | **[send_flow_data](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-send-flow-data)**(EtherType_t kind, [flow::Traffic](Classes/structllarp_1_1layers_1_1flow_1_1Traffic.md) data)<br>send datum from the os to the flow layer to be tunneled to where ever it is going.  |
| virtual std::pair< [platform::Traffic](Classes/structllarp_1_1layers_1_1platform_1_1Traffic.md), [AddressMapping](Classes/structllarp_1_1layers_1_1platform_1_1AddressMapping.md) > | **[transform_flow_traffc](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-transform-flow-traffc)**([flow::Traffic](Classes/structllarp_1_1layers_1_1flow_1_1Traffic.md) data) const<br>takes in a flow layer traffic and converts it to platform traffic, returns the platform traffic and the autovivified address mapping associated with it.  |

## Protected Attributes

|                | Name           |
| -------------- | -------------- |
| std::unordered_multimap< [flow::FlowAddr](Classes/classllarp_1_1layers_1_1flow_1_1FlowAddr.md), [flow::FlowIdentity](Classes/classllarp_1_1layers_1_1flow_1_1FlowIdentity.md) > | **[m_active_flows](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#variable-m-active-flows)** <br>this maps remote flow to local identity used for the remote.  |

## Detailed Description

```cpp
class llarp::layers::platform::PlatformDriver_Base;
```

base type that is responsible for bridging the os and the flow layer. 

all functionality that the rest of the codebase that is not below this layer interacts via this type. 

## Public Functions Documentation

### function ~PlatformDriver_Base

```cpp
virtual ~PlatformDriver_Base() =default
```


### function peek_platform

```cpp
bool peek_platform() const
```

peek if we have packets from the os to read. 

### function peek_flow

```cpp
bool peek_flow() const
```

peek if we have things from the flow layer to read. 

## Protected Functions Documentation

### function send_flow_data

```cpp
virtual void send_flow_data(
    EtherType_t kind,
    flow::Traffic data
)
```

send datum from the os to the flow layer to be tunneled to where ever it is going. 

### function transform_flow_traffc

```cpp
virtual std::pair< platform::Traffic, AddressMapping > transform_flow_traffc(
    flow::Traffic data
) const
```

takes in a flow layer traffic and converts it to platform traffic, returns the platform traffic and the autovivified address mapping associated with it. 

## Protected Attributes Documentation

### variable m_active_flows

```cpp
std::unordered_multimap< flow::FlowAddr, flow::FlowIdentity > m_active_flows;
```

this maps remote flow to local identity used for the remote. 

-------------------------------

Updated on 2023-01-17 at 19:45:13 +0000